/**
@license
Copyright 2018 Google Inc. All Rights Reserved.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
import { FormElement, HTMLElementWithRipple, RippleSurface } from '@authentic/mwc-base/form-element';
import { MDCSelectAdapter } from '@material/select/adapter';
import { MDCSelectFoundation } from '@material/select/foundation';
import { MDCSelectFoundationMap } from '@material/select/types';
import { MDCSelectIcon } from '@material/select/icon';
import { MDCSelectHelperText } from '@material/select/helper-text';
import { MDCNotchedOutline } from '@material/notched-outline';
import { MDCFloatingLabel } from '@material/floating-label';
import { MDCLineRipple } from '@material/line-ripple';
import { Menu as MWCMenu } from '@authentic/mwc-menu/mwc-menu';
import { ListItem as MWCListItem } from '@authentic/mwc-list/mwc-list-item';
declare global {
    interface HTMLElementTagNameMap {
        'mwc-select': Select;
    }
}
export declare class Select extends FormElement {
    protected mdcRoot: HTMLElementWithRipple;
    protected _hiddenInput: HTMLInputElement;
    protected _selectedText: HTMLElement;
    protected _menuAnchor: HTMLElement;
    protected slotSelect: HTMLSlotElement;
    protected slotMenu: HTMLSlotElement;
    protected labelElement: HTMLLabelElement;
    protected lineRippleElement: HTMLElement;
    protected outlineElement: HTMLElement;
    protected leadingIconElement: HTMLElement;
    protected helperTextElement: HTMLElement;
    value: string;
    label: string;
    outlined: boolean;
    disabled: boolean;
    helperTextContent: string;
    validationMessage: string;
    persistentHelperText: boolean;
    leadingIconAriaLabel: string;
    leadingIconContent: string;
    required: boolean;
    valid: boolean;
    readonly ripple: RippleSurface | undefined;
    /**
     * Enables or disables the use of native validation. Use this for custom validation.
     */
    protected _useNativeValidation: boolean;
    useNativeValidation: boolean;
    readonly slottedSelect: HTMLSelectElement | null;
    readonly slottedMenu: MWCMenu | null;
    selectedIndex: number;
    protected readonly formElement: HTMLElement;
    protected readonly selectEl: HTMLSelectElement | null;
    protected _formElementId: string;
    protected _selectedItem: MWCListItem;
    protected _isMenuOpen: boolean;
    protected _nativeControl: HTMLSelectElement | null;
    protected _leadingIcon: MDCSelectIcon;
    protected _helperText: MDCSelectHelperText | null;
    protected _lineRipple: MDCLineRipple | null;
    protected _label: MDCFloatingLabel | null;
    protected _outline: MDCNotchedOutline | null;
    protected _validationObserver: MutationObserver;
    protected _handleChange: EventListenerOrEventListenerObject;
    protected _handleFocus: EventListenerOrEventListenerObject;
    protected _handleBlur: EventListenerOrEventListenerObject;
    protected _handleClick: EventListenerOrEventListenerObject;
    protected _handleKeydown: EventListenerOrEventListenerObject;
    protected _handleMenuOpened: EventListenerOrEventListenerObject;
    protected _handleMenuClosed: EventListenerOrEventListenerObject;
    protected _handleMenuSelected: EventListenerOrEventListenerObject;
    protected mdcFoundation: MDCSelectFoundation;
    protected readonly mdcFoundationClass: typeof MDCSelectFoundation;
    createAdapter(): MDCSelectAdapter;
    protected _getNativeSelectAdapterMethods(): {
        getValue: () => string;
        setValue: (value: string) => void;
        openMenu: () => undefined;
        closeMenu: () => undefined;
        isMenuOpen: () => boolean;
        setSelectedIndex: (index: number) => void;
        setDisabled: (isDisabled: boolean) => void;
        setValid: (isValid: boolean) => void;
        checkValidity: () => boolean;
    };
    protected _getEnhancedSelectAdapterMethods(): {
        getValue: () => string;
        setValue: (value: string) => void;
        openMenu: () => void;
        closeMenu: () => void;
        isMenuOpen: () => boolean;
        setSelectedIndex: (index: number) => void;
        setDisabled: (isDisabled: boolean) => void;
        checkValidity: () => boolean;
        setValid: (isValid: boolean) => void;
    };
    protected _getCommonAdapterMethods(): {
        addClass: (className: any) => void;
        removeClass: (className: any) => void;
        hasClass: (className: any) => boolean;
        setRippleCenter: (normalizedX: any) => void | null;
        activateBottomLine: () => void | null;
        deactivateBottomLine: () => void | null;
        notifyChange: (value: any) => void;
    };
    protected _getOutlineAdapterMethods(): {
        hasOutline: () => boolean;
        notchOutline: (labelWidth: any) => void | null;
        closeOutline: () => void | null;
    };
    protected _getLabelAdapterMethods(): {
        floatLabel: (shouldFloat: any) => void | null;
        getLabelWidth: () => number;
    };
    static styles: import("lit-element/lib/css-tag").CSSResult;
    _renderFloatingLabel(): import("lit-html/lib/template-result").TemplateResult;
    _renderNotchedOutline(): import("lit-html/lib/template-result").TemplateResult;
    _renderLineRipple(): import("lit-html/lib/template-result").TemplateResult;
    _renderHelperText(): import("lit-html/lib/template-result").TemplateResult;
    _renderLeadingIcon(): import("lit-html/lib/template-result").TemplateResult;
    render(): import("lit-html/lib/template-result").TemplateResult;
    firstUpdated(): void;
    connectedCallback(): void;
    createFoundation(): void;
    /**
     * Handle change event
     */
    protected _onChange(evt: any): void;
    /**
     * Handle focus event
     */
    protected _onFocus(evt: any): void;
    /**
     * Handle blur event
     */
    protected _onBlur(evt: any): void;
    /**
     * Handle click event
     */
    protected _onClick(evt: any): void;
    /**
     * Handle keydown event
     */
    protected _onKeydown(evt: any): void;
    /**
     * Handle menu opened event
     */
    protected _onMenuOpened(): void;
    /**
     * Handle menu closed event
     */
    protected _onMenuClosed(): void;
    /**
     * Handle menu selected event
     */
    protected _onMenuSelected(evt: any): void;
    /**
     * Handles setup for the native control
     */
    protected _nativeSelectSetup(): void;
    /**
     * Handles setup for the enhanced menu.
     */
    protected _enhancedSelectSetup(): void;
    /**
     * Calculates where the line ripple should start based on the x coordinate within the component.
     */
    protected _getNormalizedXCoordinate(evt: MouseEvent | TouchEvent): number;
    protected isTouchEvent_(evt: MouseEvent | TouchEvent): evt is TouchEvent;
    protected _setValidity(isValid: boolean): void;
    /**
     * Returns a map of all subcomponents to subfoundations.
     */
    protected _getFoundationMap(): Partial<MDCSelectFoundationMap>;
    protected _setNativeSelectedIndex(index: number): void;
    protected _setEnhancedSelectedIndex(index: number): void;
    protected _initialSyncRequiredState(): void;
    protected _addMutationObserverForRequired(): void;
    /**
     * Recomputes the outline SVG path for the outline element.
     */
    layout(): void;
}
